aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPřemysl Eric Janouch <p@janouch.name>2020-10-31 13:42:56 +0100
committerPřemysl Eric Janouch <p@janouch.name>2020-10-31 13:42:56 +0100
commit8ccf38ad76ada5df87532d137ba73a4abf1f3839 (patch)
tree70e4198b546ba6e31f67a7fa30bde442df681a8c
parent47a4c8beca44d5c07516418c348d77aba5b554fc (diff)
downloadxK-8ccf38ad76ada5df87532d137ba73a4abf1f3839.tar.gz
xK-8ccf38ad76ada5df87532d137ba73a4abf1f3839.tar.xz
xK-8ccf38ad76ada5df87532d137ba73a4abf1f3839.zip
Minor rebranding
There's nothing experimental about this project anymore. It's stable. Maybe we should add a photo of Hitler or something.
-rw-r--r--CMakeLists.txt2
-rw-r--r--README.adoc4
-rw-r--r--degesch.adoc2
-rw-r--r--degesch.c4
-rw-r--r--kike.adoc2
-rw-r--r--kike.c4
-rw-r--r--zyklonb.adoc2
-rw-r--r--zyklonb.c4
8 files changed, 12 insertions, 12 deletions
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 540c3c3..e0a443b 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -216,7 +216,7 @@ foreach (page ${project_MAN_PAGES})
endforeach ()
# CPack
-set (CPACK_PACKAGE_DESCRIPTION_SUMMARY "Experimental IRC client, daemon and bot")
+set (CPACK_PACKAGE_DESCRIPTION_SUMMARY "Unethical IRC client, daemon and bot")
set (CPACK_PACKAGE_VERSION "${project_version_safe}")
set (CPACK_PACKAGE_VENDOR "Premysl Eric Janouch")
set (CPACK_PACKAGE_CONTACT "Přemysl Eric Janouch <p@janouch.name>")
diff --git a/README.adoc b/README.adoc
index 5c3eb6c..a171e7f 100644
--- a/README.adoc
+++ b/README.adoc
@@ -3,8 +3,8 @@ uirc3
:compact-option:
The [line-through]#unethical# edgy IRC trinity. This project consists of an
-experimental IRC client, daemon, and bot. It's all you're ever going to need
-for chatting, as long as you can make do with minimalist software.
+IRC client, daemon, and bot. It's all you're ever going to need for chatting,
+as long as you can make do with minimalist software.
All of them have these potentially interesting properties:
diff --git a/degesch.adoc b/degesch.adoc
index 63e46b4..f3c7904 100644
--- a/degesch.adoc
+++ b/degesch.adoc
@@ -6,7 +6,7 @@ degesch(1)
Name
----
-degesch - an experimental IRC client
+degesch - terminal-based IRC client
Synopsis
--------
diff --git a/kike.adoc b/kike.adoc
index e97cba2..0807c78 100644
--- a/kike.adoc
+++ b/kike.adoc
@@ -6,7 +6,7 @@ kike(1)
Name
----
-kike - an experimental IRC daemon
+kike - IRC daemon
Synopsis
--------
diff --git a/kike.c b/kike.c
index 68e71c0..0f57c44 100644
--- a/kike.c
+++ b/kike.c
@@ -1,5 +1,5 @@
/*
- * kike.c: the experimental IRC daemon
+ * kike.c: an IRC daemon
*
* Copyright (c) 2014 - 2020, Přemysl Eric Janouch <p@janouch.name>
*
@@ -3991,7 +3991,7 @@ main (int argc, char *argv[])
};
struct opt_handler oh =
- opt_handler_make (argc, argv, opts, NULL, "Experimental IRC daemon.");
+ opt_handler_make (argc, argv, opts, NULL, "IRC daemon.");
int c;
while ((c = opt_handler_get (&oh)) != -1)
diff --git a/zyklonb.adoc b/zyklonb.adoc
index d02368f..b4730cb 100644
--- a/zyklonb.adoc
+++ b/zyklonb.adoc
@@ -6,7 +6,7 @@ zyklonb(1)
Name
----
-zyklonb - an experimental IRC bot
+zyklonb - modular IRC bot
Synopsis
--------
diff --git a/degesch.c b/degesch.c
index f1168d6..30cf634 100644
--- a/degesch.c
+++ b/degesch.c
@@ -1,5 +1,5 @@
/*
* degesch.c: the experimental IRC client
*
* Copyright (c) 2015 - 2020, Přemysl Eric Janouch <p@janouch.name>
*
@@ -14064,7 +14064,7 @@ main (int argc, char *argv[])
};
struct opt_handler oh =
- opt_handler_make (argc, argv, opts, NULL, "Experimental IRC client.");
+ opt_handler_make (argc, argv, opts, NULL, "Terminal-based IRC client.");
bool format_mode = false;
int c;
@@ -1,5 +1,5 @@
/*
- * degesch.c: the experimental IRC client
+ * degesch.c: a terminal-based IRC client
*
* Copyright (c) 2015 - 2020, Přemysl Eric Janouch <p@janouch.name>
diff --git a/zyklonb.c b/zyklonb.c
index 9a37af8..08ffb1b 100644
--- a/zyklonb.c
+++ b/zyklonb.c
@@ -1,5 +1,5 @@
/*
* zyklonb.c: the experimental IRC bot
*
* Copyright (c) 2014 - 2020, Přemysl Eric Janouch <p@janouch.name>
*
@@ -1983,7 +1983,7 @@ main (int argc, char *argv[])
};
struct opt_handler oh =
- opt_handler_make (argc, argv, opts, NULL, "Experimental IRC bot.");
+ opt_handler_make (argc, argv, opts, NULL, "Modular IRC bot.");
int c;
while ((c = opt_handler_get (&oh)) != -1)
@@ -1,5 +1,5 @@
/*
- * zyklonb.c: the experimental IRC bot
+ * zyklonb.c: a modular IRC bot
*
* Copyright (c) 2014 - 2020, Přemysl Eric Janouch <p@janouch.name>